# coding=utf-8
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    Addon,
    AddonCreate,
    AddonReplaceUpdate,
    Address,
    Alignment,
    Annotations,
    AppCapability,
    AppPaginatedResponse,
    AppReference,
    BadRequestProblemResponse,
    BalanceHistoryWindow,
    BillingCustomerProfile,
    BillingDiscountPercentage,
    BillingDiscountUsage,
    BillingDiscounts,
    BillingInvoiceCustomerExtendedDetails,
    BillingParty,
    BillingPartyReplaceUpdate,
    BillingPartyTaxIdentity,
    BillingProfile,
    BillingProfileAppReferences,
    BillingProfileApps,
    BillingProfileAppsCreate,
    BillingProfileCreate,
    BillingProfileCustomerOverride,
    BillingProfileCustomerOverrideCreate,
    BillingProfileCustomerOverrideWithDetails,
    BillingProfileCustomerOverrideWithDetailsPaginatedResponse,
    BillingProfilePaginatedResponse,
    BillingProfileReplaceUpdateWithWorkflow,
    BillingWorkflow,
    BillingWorkflowCollectionAlignmentAnchored,
    BillingWorkflowCollectionAlignmentSubscription,
    BillingWorkflowCollectionSettings,
    BillingWorkflowCreate,
    BillingWorkflowInvoicingSettings,
    BillingWorkflowPaymentSettings,
    BillingWorkflowTaxSettings,
    CancelRequest,
    CheckoutSessionCustomTextAfterSubmitParams,
    CheckoutSessionCustomTextParamsAfterSubmit,
    CheckoutSessionCustomTextParamsShippingAddress,
    CheckoutSessionCustomTextParamsSubmit,
    CheckoutSessionCustomTextParamsTermsOfServiceAcceptance,
    ClientAppStartResponse,
    ConflictProblemResponse,
    CreateCheckoutSessionTaxIdCollection,
    CreateResponseExtensions,
    CreateStripeCheckoutSessionConsentCollection,
    CreateStripeCheckoutSessionConsentCollectionPaymentMethodReuseAgreement,
    CreateStripeCheckoutSessionCustomerUpdate,
    CreateStripeCheckoutSessionRequest,
    CreateStripeCheckoutSessionRequestOptions,
    CreateStripeCheckoutSessionResult,
    CreateStripeCustomerPortalSessionParams,
    CreditNoteOriginalInvoiceRef,
    Currency,
    CustomInvoicingApp,
    CustomInvoicingAppReplaceUpdate,
    CustomInvoicingCustomerAppData,
    CustomInvoicingDraftSynchronizedRequest,
    CustomInvoicingFinalizedInvoicingRequest,
    CustomInvoicingFinalizedPaymentRequest,
    CustomInvoicingFinalizedRequest,
    CustomInvoicingLineDiscountExternalIdMapping,
    CustomInvoicingLineExternalIdMapping,
    CustomInvoicingSyncResult,
    CustomInvoicingTaxConfig,
    CustomInvoicingUpdatePaymentStatusRequest,
    CustomPlanInput,
    CustomSubscriptionChange,
    CustomSubscriptionCreate,
    Customer,
    CustomerAccess,
    CustomerAppDataPaginatedResponse,
    CustomerCreate,
    CustomerId,
    CustomerKey,
    CustomerPaginatedResponse,
    CustomerReplaceUpdate,
    CustomerUsageAttribution,
    DiscountPercentage,
    DiscountReasonMaximumSpend,
    DiscountReasonRatecardPercentage,
    DiscountReasonRatecardUsage,
    DiscountUsage,
    Discounts,
    DynamicPriceWithCommitments,
    EditSubscriptionAddItem,
    EditSubscriptionAddPhase,
    EditSubscriptionRemoveItem,
    EditSubscriptionRemovePhase,
    EditSubscriptionStretchPhase,
    EditSubscriptionUnscheduleEdit,
    EntitlementBoolean,
    EntitlementBooleanCreateInputs,
    EntitlementBooleanV2,
    EntitlementGrant,
    EntitlementGrantCreateInput,
    EntitlementGrantCreateInputV2,
    EntitlementGrantV2,
    EntitlementMetered,
    EntitlementMeteredCreateInputs,
    EntitlementMeteredV2,
    EntitlementMeteredV2CreateInputs,
    EntitlementPaginatedResponse,
    EntitlementStatic,
    EntitlementStaticCreateInputs,
    EntitlementStaticV2,
    EntitlementV2PaginatedResponse,
    EntitlementValue,
    EntitlementValueV2,
    ErrorExtension,
    Event,
    EventDeliveryAttemptResponse,
    ExpirationPeriod,
    Feature,
    FeatureCreateInputs,
    FeatureLLMUnitCost,
    FeatureLLMUnitCostPricing,
    FeatureManualUnitCost,
    FeatureMeta,
    FeaturePaginatedResponse,
    FilterIDExact,
    FilterString,
    FilterTime,
    FlatPrice,
    FlatPriceWithPaymentTerm,
    ForbiddenProblemResponse,
    GrantBurnDownHistorySegment,
    GrantPaginatedResponse,
    GrantUsageRecord,
    GrantV2PaginatedResponse,
    IDResource,
    IngestedEvent,
    InstallWithApiKeyRequest,
    InternalServerErrorProblemResponse,
    Invoice,
    InvoiceAppExternalIds,
    InvoiceAvailableActionDetails,
    InvoiceAvailableActionInvoiceDetails,
    InvoiceAvailableActions,
    InvoiceDetailedLine,
    InvoiceDetailedLineRateCard,
    InvoiceGenericDocumentRef,
    InvoiceLine,
    InvoiceLineAmountDiscount,
    InvoiceLineAppExternalIds,
    InvoiceLineDiscounts,
    InvoiceLineReplaceUpdate,
    InvoiceLineSubscriptionReference,
    InvoiceLineTaxItem,
    InvoiceLineUsageDiscount,
    InvoicePaginatedResponse,
    InvoicePaymentTerms,
    InvoicePendingLineCreate,
    InvoicePendingLineCreateInput,
    InvoicePendingLineCreateResponse,
    InvoicePendingLinesActionFiltersInput,
    InvoicePendingLinesActionInput,
    InvoiceReference,
    InvoiceReplaceUpdate,
    InvoiceSimulationInput,
    InvoiceSimulationLine,
    InvoiceStatusDetails,
    InvoiceTotals,
    InvoiceUsageBasedRateCard,
    InvoiceWorkflowInvoicingSettingsReplaceUpdate,
    InvoiceWorkflowReplaceUpdate,
    InvoiceWorkflowSettings,
    InvoiceWorkflowSettingsReplaceUpdate,
    IssueAfterReset,
    ListRequestFilter,
    MarketplaceInstallRequestPayload,
    MarketplaceInstallResponse,
    MarketplaceListing,
    MarketplaceListingPaginatedResponse,
    Metadata,
    Meter,
    MeterCreate,
    MeterQueryRequest,
    MeterQueryResult,
    MeterQueryRow,
    MeterUpdate,
    MigrateRequest,
    NotFoundProblemResponse,
    NotificationChannelMeta,
    NotificationChannelPaginatedResponse,
    NotificationChannelWebhook,
    NotificationChannelWebhookCreateRequest,
    NotificationEvent,
    NotificationEventBalanceThresholdPayload,
    NotificationEventBalanceThresholdPayloadData,
    NotificationEventDeliveryAttempt,
    NotificationEventDeliveryStatus,
    NotificationEventEntitlementValuePayloadBase,
    NotificationEventInvoiceCreatedPayload,
    NotificationEventInvoiceUpdatedPayload,
    NotificationEventPaginatedResponse,
    NotificationEventResendRequest,
    NotificationEventResetPayload,
    NotificationRuleBalanceThreshold,
    NotificationRuleBalanceThresholdCreateRequest,
    NotificationRuleBalanceThresholdValue,
    NotificationRuleEntitlementReset,
    NotificationRuleEntitlementResetCreateRequest,
    NotificationRuleInvoiceCreated,
    NotificationRuleInvoiceCreatedCreateRequest,
    NotificationRuleInvoiceUpdated,
    NotificationRuleInvoiceUpdatedCreateRequest,
    NotificationRulePaginatedResponse,
    OmitPropertiesResourceCreateModel,
    PackagePriceWithCommitments,
    PaymentDueDate,
    PaymentTermDueDate,
    PaymentTermInstant,
    Period,
    Plan,
    PlanAddon,
    PlanAddonCreate,
    PlanAddonPaginatedResponse,
    PlanAddonReplaceUpdate,
    PlanCreate,
    PlanPhase,
    PlanReference,
    PlanReferenceInput,
    PlanReplaceUpdate,
    PlanSubscriptionChange,
    PlanSubscriptionCreate,
    PortalToken,
    PreconditionFailedProblemResponse,
    PriceTier,
    ProRatingConfig,
    Progress,
    RateCardBooleanEntitlement,
    RateCardFlatFee,
    RateCardMeteredEntitlement,
    RateCardStaticEntitlement,
    RateCardUsageBased,
    RecurringPeriod,
    RecurringPeriodCreateInput,
    RecurringPeriodV2,
    ResetEntitlementUsageInput,
    SandboxApp,
    SandboxAppReplaceUpdate,
    SandboxCustomerAppData,
    ServiceUnavailableProblemResponse,
    StripeAPIKeyInput,
    StripeApp,
    StripeAppReplaceUpdate,
    StripeCustomerAppData,
    StripeCustomerAppDataBase,
    StripeCustomerPortalSession,
    StripeTaxConfig,
    StripeWebhookEvent,
    StripeWebhookEventData,
    StripeWebhookResponse,
    Subject,
    SubjectUpsert,
    Subscription,
    SubscriptionAddon,
    SubscriptionAddonAddon,
    SubscriptionAddonCreate,
    SubscriptionAddonCreateAddon,
    SubscriptionAddonRateCard,
    SubscriptionAddonTimelineSegment,
    SubscriptionAddonUpdate,
    SubscriptionAlignment,
    SubscriptionBadRequestErrorResponse,
    SubscriptionChangeResponseBody,
    SubscriptionConflictErrorResponse,
    SubscriptionEdit,
    SubscriptionExpanded,
    SubscriptionItem,
    SubscriptionItemIncluded,
    SubscriptionPaginatedResponse,
    SubscriptionPhaseCreate,
    SubscriptionPhaseExpanded,
    TaxConfig,
    TieredPriceWithCommitments,
    UnauthorizedProblemResponse,
    UnexpectedProblemResponse,
    UnitPrice,
    UnitPriceWithCommitments,
    ValidationError,
    ValidationIssue,
    VoidInvoiceAction,
    VoidInvoiceActionInput,
    VoidInvoiceActionLineOverride,
    VoidInvoiceLineDiscardAction,
    VoidInvoiceLinePendingAction,
    WindowedBalanceHistory,
)

from ._enums import (  # type: ignore
    AddonInstanceType,
    AddonOrderBy,
    AddonStatus,
    AppCapabilityType,
    AppStatus,
    AppType,
    BillingCollectionAlignment,
    BillingProfileCustomerOverrideExpand,
    BillingProfileCustomerOverrideOrderBy,
    BillingProfileExpand,
    BillingProfileOrderBy,
    CheckoutSessionUIMode,
    CollectionMethod,
    CreateCheckoutSessionTaxIdCollectionRequired,
    CreateStripeCheckoutSessionBillingAddressCollection,
    CreateStripeCheckoutSessionConsentCollectionPaymentMethodReuseAgreementPosition,
    CreateStripeCheckoutSessionConsentCollectionPromotions,
    CreateStripeCheckoutSessionConsentCollectionTermsOfService,
    CreateStripeCheckoutSessionCustomerUpdateBehavior,
    CreateStripeCheckoutSessionRedirectOnCompletion,
    CustomInvoicingPaymentTrigger,
    CustomerExpand,
    CustomerOrderBy,
    CustomerSubscriptionOrderBy,
    DiscountReasonType,
    EditOp,
    EntitlementOrderBy,
    EntitlementType,
    ExpirationDuration,
    FeatureOrderBy,
    FeatureUnitCostType,
    GrantOrderBy,
    InstallMethod,
    InvoiceDetailedLineCostCategory,
    InvoiceDocumentRefType,
    InvoiceExpand,
    InvoiceLineManagedBy,
    InvoiceLineStatus,
    InvoiceLineTaxBehavior,
    InvoiceLineTypes,
    InvoiceOrderBy,
    InvoiceStatus,
    InvoiceType,
    MeasureUsageFromPreset,
    MeterAggregation,
    MeterOrderBy,
    NotificationChannelOrderBy,
    NotificationChannelType,
    NotificationEventDeliveryStatusState,
    NotificationEventOrderBy,
    NotificationEventType,
    NotificationRuleBalanceThresholdValueType,
    NotificationRuleOrderBy,
    OAuth2AuthorizationCodeGrantErrorType,
    PaymentTermType,
    PlanAddonOrderBy,
    PlanOrderBy,
    PlanStatus,
    PricePaymentTerm,
    PriceType,
    ProRatingMode,
    RateCardType,
    RecurringPeriodIntervalEnum,
    RemovePhaseShifting,
    SortOrder,
    StripeCheckoutSessionMode,
    SubscriptionStatus,
    SubscriptionTimingEnum,
    TaxBehavior,
    TieredPriceMode,
    ValidationIssueSeverity,
    VoidInvoiceLineActionType,
    WindowSize,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Addon",
    "AddonCreate",
    "AddonReplaceUpdate",
    "Address",
    "Alignment",
    "Annotations",
    "AppCapability",
    "AppPaginatedResponse",
    "AppReference",
    "BadRequestProblemResponse",
    "BalanceHistoryWindow",
    "BillingCustomerProfile",
    "BillingDiscountPercentage",
    "BillingDiscountUsage",
    "BillingDiscounts",
    "BillingInvoiceCustomerExtendedDetails",
    "BillingParty",
    "BillingPartyReplaceUpdate",
    "BillingPartyTaxIdentity",
    "BillingProfile",
    "BillingProfileAppReferences",
    "BillingProfileApps",
    "BillingProfileAppsCreate",
    "BillingProfileCreate",
    "BillingProfileCustomerOverride",
    "BillingProfileCustomerOverrideCreate",
    "BillingProfileCustomerOverrideWithDetails",
    "BillingProfileCustomerOverrideWithDetailsPaginatedResponse",
    "BillingProfilePaginatedResponse",
    "BillingProfileReplaceUpdateWithWorkflow",
    "BillingWorkflow",
    "BillingWorkflowCollectionAlignmentAnchored",
    "BillingWorkflowCollectionAlignmentSubscription",
    "BillingWorkflowCollectionSettings",
    "BillingWorkflowCreate",
    "BillingWorkflowInvoicingSettings",
    "BillingWorkflowPaymentSettings",
    "BillingWorkflowTaxSettings",
    "CancelRequest",
    "CheckoutSessionCustomTextAfterSubmitParams",
    "CheckoutSessionCustomTextParamsAfterSubmit",
    "CheckoutSessionCustomTextParamsShippingAddress",
    "CheckoutSessionCustomTextParamsSubmit",
    "CheckoutSessionCustomTextParamsTermsOfServiceAcceptance",
    "ClientAppStartResponse",
    "ConflictProblemResponse",
    "CreateCheckoutSessionTaxIdCollection",
    "CreateResponseExtensions",
    "CreateStripeCheckoutSessionConsentCollection",
    "CreateStripeCheckoutSessionConsentCollectionPaymentMethodReuseAgreement",
    "CreateStripeCheckoutSessionCustomerUpdate",
    "CreateStripeCheckoutSessionRequest",
    "CreateStripeCheckoutSessionRequestOptions",
    "CreateStripeCheckoutSessionResult",
    "CreateStripeCustomerPortalSessionParams",
    "CreditNoteOriginalInvoiceRef",
    "Currency",
    "CustomInvoicingApp",
    "CustomInvoicingAppReplaceUpdate",
    "CustomInvoicingCustomerAppData",
    "CustomInvoicingDraftSynchronizedRequest",
    "CustomInvoicingFinalizedInvoicingRequest",
    "CustomInvoicingFinalizedPaymentRequest",
    "CustomInvoicingFinalizedRequest",
    "CustomInvoicingLineDiscountExternalIdMapping",
    "CustomInvoicingLineExternalIdMapping",
    "CustomInvoicingSyncResult",
    "CustomInvoicingTaxConfig",
    "CustomInvoicingUpdatePaymentStatusRequest",
    "CustomPlanInput",
    "CustomSubscriptionChange",
    "CustomSubscriptionCreate",
    "Customer",
    "CustomerAccess",
    "CustomerAppDataPaginatedResponse",
    "CustomerCreate",
    "CustomerId",
    "CustomerKey",
    "CustomerPaginatedResponse",
    "CustomerReplaceUpdate",
    "CustomerUsageAttribution",
    "DiscountPercentage",
    "DiscountReasonMaximumSpend",
    "DiscountReasonRatecardPercentage",
    "DiscountReasonRatecardUsage",
    "DiscountUsage",
    "Discounts",
    "DynamicPriceWithCommitments",
    "EditSubscriptionAddItem",
    "EditSubscriptionAddPhase",
    "EditSubscriptionRemoveItem",
    "EditSubscriptionRemovePhase",
    "EditSubscriptionStretchPhase",
    "EditSubscriptionUnscheduleEdit",
    "EntitlementBoolean",
    "EntitlementBooleanCreateInputs",
    "EntitlementBooleanV2",
    "EntitlementGrant",
    "EntitlementGrantCreateInput",
    "EntitlementGrantCreateInputV2",
    "EntitlementGrantV2",
    "EntitlementMetered",
    "EntitlementMeteredCreateInputs",
    "EntitlementMeteredV2",
    "EntitlementMeteredV2CreateInputs",
    "EntitlementPaginatedResponse",
    "EntitlementStatic",
    "EntitlementStaticCreateInputs",
    "EntitlementStaticV2",
    "EntitlementV2PaginatedResponse",
    "EntitlementValue",
    "EntitlementValueV2",
    "ErrorExtension",
    "Event",
    "EventDeliveryAttemptResponse",
    "ExpirationPeriod",
    "Feature",
    "FeatureCreateInputs",
    "FeatureLLMUnitCost",
    "FeatureLLMUnitCostPricing",
    "FeatureManualUnitCost",
    "FeatureMeta",
    "FeaturePaginatedResponse",
    "FilterIDExact",
    "FilterString",
    "FilterTime",
    "FlatPrice",
    "FlatPriceWithPaymentTerm",
    "ForbiddenProblemResponse",
    "GrantBurnDownHistorySegment",
    "GrantPaginatedResponse",
    "GrantUsageRecord",
    "GrantV2PaginatedResponse",
    "IDResource",
    "IngestedEvent",
    "InstallWithApiKeyRequest",
    "InternalServerErrorProblemResponse",
    "Invoice",
    "InvoiceAppExternalIds",
    "InvoiceAvailableActionDetails",
    "InvoiceAvailableActionInvoiceDetails",
    "InvoiceAvailableActions",
    "InvoiceDetailedLine",
    "InvoiceDetailedLineRateCard",
    "InvoiceGenericDocumentRef",
    "InvoiceLine",
    "InvoiceLineAmountDiscount",
    "InvoiceLineAppExternalIds",
    "InvoiceLineDiscounts",
    "InvoiceLineReplaceUpdate",
    "InvoiceLineSubscriptionReference",
    "InvoiceLineTaxItem",
    "InvoiceLineUsageDiscount",
    "InvoicePaginatedResponse",
    "InvoicePaymentTerms",
    "InvoicePendingLineCreate",
    "InvoicePendingLineCreateInput",
    "InvoicePendingLineCreateResponse",
    "InvoicePendingLinesActionFiltersInput",
    "InvoicePendingLinesActionInput",
    "InvoiceReference",
    "InvoiceReplaceUpdate",
    "InvoiceSimulationInput",
    "InvoiceSimulationLine",
    "InvoiceStatusDetails",
    "InvoiceTotals",
    "InvoiceUsageBasedRateCard",
    "InvoiceWorkflowInvoicingSettingsReplaceUpdate",
    "InvoiceWorkflowReplaceUpdate",
    "InvoiceWorkflowSettings",
    "InvoiceWorkflowSettingsReplaceUpdate",
    "IssueAfterReset",
    "ListRequestFilter",
    "MarketplaceInstallRequestPayload",
    "MarketplaceInstallResponse",
    "MarketplaceListing",
    "MarketplaceListingPaginatedResponse",
    "Metadata",
    "Meter",
    "MeterCreate",
    "MeterQueryRequest",
    "MeterQueryResult",
    "MeterQueryRow",
    "MeterUpdate",
    "MigrateRequest",
    "NotFoundProblemResponse",
    "NotificationChannelMeta",
    "NotificationChannelPaginatedResponse",
    "NotificationChannelWebhook",
    "NotificationChannelWebhookCreateRequest",
    "NotificationEvent",
    "NotificationEventBalanceThresholdPayload",
    "NotificationEventBalanceThresholdPayloadData",
    "NotificationEventDeliveryAttempt",
    "NotificationEventDeliveryStatus",
    "NotificationEventEntitlementValuePayloadBase",
    "NotificationEventInvoiceCreatedPayload",
    "NotificationEventInvoiceUpdatedPayload",
    "NotificationEventPaginatedResponse",
    "NotificationEventResendRequest",
    "NotificationEventResetPayload",
    "NotificationRuleBalanceThreshold",
    "NotificationRuleBalanceThresholdCreateRequest",
    "NotificationRuleBalanceThresholdValue",
    "NotificationRuleEntitlementReset",
    "NotificationRuleEntitlementResetCreateRequest",
    "NotificationRuleInvoiceCreated",
    "NotificationRuleInvoiceCreatedCreateRequest",
    "NotificationRuleInvoiceUpdated",
    "NotificationRuleInvoiceUpdatedCreateRequest",
    "NotificationRulePaginatedResponse",
    "OmitPropertiesResourceCreateModel",
    "PackagePriceWithCommitments",
    "PaymentDueDate",
    "PaymentTermDueDate",
    "PaymentTermInstant",
    "Period",
    "Plan",
    "PlanAddon",
    "PlanAddonCreate",
    "PlanAddonPaginatedResponse",
    "PlanAddonReplaceUpdate",
    "PlanCreate",
    "PlanPhase",
    "PlanReference",
    "PlanReferenceInput",
    "PlanReplaceUpdate",
    "PlanSubscriptionChange",
    "PlanSubscriptionCreate",
    "PortalToken",
    "PreconditionFailedProblemResponse",
    "PriceTier",
    "ProRatingConfig",
    "Progress",
    "RateCardBooleanEntitlement",
    "RateCardFlatFee",
    "RateCardMeteredEntitlement",
    "RateCardStaticEntitlement",
    "RateCardUsageBased",
    "RecurringPeriod",
    "RecurringPeriodCreateInput",
    "RecurringPeriodV2",
    "ResetEntitlementUsageInput",
    "SandboxApp",
    "SandboxAppReplaceUpdate",
    "SandboxCustomerAppData",
    "ServiceUnavailableProblemResponse",
    "StripeAPIKeyInput",
    "StripeApp",
    "StripeAppReplaceUpdate",
    "StripeCustomerAppData",
    "StripeCustomerAppDataBase",
    "StripeCustomerPortalSession",
    "StripeTaxConfig",
    "StripeWebhookEvent",
    "StripeWebhookEventData",
    "StripeWebhookResponse",
    "Subject",
    "SubjectUpsert",
    "Subscription",
    "SubscriptionAddon",
    "SubscriptionAddonAddon",
    "SubscriptionAddonCreate",
    "SubscriptionAddonCreateAddon",
    "SubscriptionAddonRateCard",
    "SubscriptionAddonTimelineSegment",
    "SubscriptionAddonUpdate",
    "SubscriptionAlignment",
    "SubscriptionBadRequestErrorResponse",
    "SubscriptionChangeResponseBody",
    "SubscriptionConflictErrorResponse",
    "SubscriptionEdit",
    "SubscriptionExpanded",
    "SubscriptionItem",
    "SubscriptionItemIncluded",
    "SubscriptionPaginatedResponse",
    "SubscriptionPhaseCreate",
    "SubscriptionPhaseExpanded",
    "TaxConfig",
    "TieredPriceWithCommitments",
    "UnauthorizedProblemResponse",
    "UnexpectedProblemResponse",
    "UnitPrice",
    "UnitPriceWithCommitments",
    "ValidationError",
    "ValidationIssue",
    "VoidInvoiceAction",
    "VoidInvoiceActionInput",
    "VoidInvoiceActionLineOverride",
    "VoidInvoiceLineDiscardAction",
    "VoidInvoiceLinePendingAction",
    "WindowedBalanceHistory",
    "AddonInstanceType",
    "AddonOrderBy",
    "AddonStatus",
    "AppCapabilityType",
    "AppStatus",
    "AppType",
    "BillingCollectionAlignment",
    "BillingProfileCustomerOverrideExpand",
    "BillingProfileCustomerOverrideOrderBy",
    "BillingProfileExpand",
    "BillingProfileOrderBy",
    "CheckoutSessionUIMode",
    "CollectionMethod",
    "CreateCheckoutSessionTaxIdCollectionRequired",
    "CreateStripeCheckoutSessionBillingAddressCollection",
    "CreateStripeCheckoutSessionConsentCollectionPaymentMethodReuseAgreementPosition",
    "CreateStripeCheckoutSessionConsentCollectionPromotions",
    "CreateStripeCheckoutSessionConsentCollectionTermsOfService",
    "CreateStripeCheckoutSessionCustomerUpdateBehavior",
    "CreateStripeCheckoutSessionRedirectOnCompletion",
    "CustomInvoicingPaymentTrigger",
    "CustomerExpand",
    "CustomerOrderBy",
    "CustomerSubscriptionOrderBy",
    "DiscountReasonType",
    "EditOp",
    "EntitlementOrderBy",
    "EntitlementType",
    "ExpirationDuration",
    "FeatureOrderBy",
    "FeatureUnitCostType",
    "GrantOrderBy",
    "InstallMethod",
    "InvoiceDetailedLineCostCategory",
    "InvoiceDocumentRefType",
    "InvoiceExpand",
    "InvoiceLineManagedBy",
    "InvoiceLineStatus",
    "InvoiceLineTaxBehavior",
    "InvoiceLineTypes",
    "InvoiceOrderBy",
    "InvoiceStatus",
    "InvoiceType",
    "MeasureUsageFromPreset",
    "MeterAggregation",
    "MeterOrderBy",
    "NotificationChannelOrderBy",
    "NotificationChannelType",
    "NotificationEventDeliveryStatusState",
    "NotificationEventOrderBy",
    "NotificationEventType",
    "NotificationRuleBalanceThresholdValueType",
    "NotificationRuleOrderBy",
    "OAuth2AuthorizationCodeGrantErrorType",
    "PaymentTermType",
    "PlanAddonOrderBy",
    "PlanOrderBy",
    "PlanStatus",
    "PricePaymentTerm",
    "PriceType",
    "ProRatingMode",
    "RateCardType",
    "RecurringPeriodIntervalEnum",
    "RemovePhaseShifting",
    "SortOrder",
    "StripeCheckoutSessionMode",
    "SubscriptionStatus",
    "SubscriptionTimingEnum",
    "TaxBehavior",
    "TieredPriceMode",
    "ValidationIssueSeverity",
    "VoidInvoiceLineActionType",
    "WindowSize",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
